@@ -1,4 +1,4 @@
-/* Copyright 2007-2009,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2009,2011,2014,2021 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -44,13 +44,17 @@
 /**                routines.                               **/
 /**                                                        **/
 /**                # Version P0.0 : from : 01 apr 1997     **/
-/**                                 to     20 jun 1997     **/
+/**                                 to   : 20 jun 1997     **/
 /**                # Version P0.1 : from : 14 apr 1998     **/
-/**                                 to     20 jun 1998     **/
+/**                                 to   : 20 jun 1998     **/
 /**                # Version 5.0  : from : 28 feb 2006     **/
-/**                                 to     05 feb 2008     **/
+/**                                 to   : 05 feb 2008     **/
 /**                # Version 5.1  : from : 28 aug 2008     **/
-/**                                 to     22 feb 2011     **/
+/**                                 to   : 22 feb 2011     **/
+/**                # Version 6.0  : from : 29 oct 2014     **/
+/**                                 to   : 29 oct 2014     **/
+/**                # Version 6.1  : from : 05 apr 2021     **/
+/**                                 to   : 05 apr 2021     **/
 /**                                                        **/
 /************************************************************/
 
@@ -193,6 +197,9 @@ int ** const                  senddspptr,         /* Pointers to communication d
 int ** const                  recvdspptr,
 MPI_Request ** const          requptr)            /* Pointer to local request array for point-to-point */
 {
+#if ((defined MPI_VERSION) && (MPI_VERSION >= 3))
+  MPI_Aint              attrglbtmp;               /* Lower bound of attribute datatype (not used)            */
+#endif /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
   MPI_Aint              attrglbsiz;               /* Extent of attribute datatype                            */
   int                   procngbsiz;               /* Size of request array for point-to-point communications */
   int                   procngbnum;
@@ -206,7 +213,11 @@ MPI_Request ** const          requptr)            /* Pointer to local request ar
 
   procngbsiz = ((grafptr->flagval & DGRAPHCOMMPTOP) != 0) ? grafptr->procngbnbr : 0;
 
+#if ((defined MPI_VERSION) && (MPI_VERSION >= 3))
+  MPI_Type_get_extent (attrglbtype, &attrglbtmp, &attrglbsiz); /* Get type extent */
+#else /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
   MPI_Type_extent (attrglbtype, &attrglbsiz);     /* Get type extent */
+#endif /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
   if (memAllocGroup ((void **) (void *)
                      attrsndptr, (size_t) (grafptr->procsndnbr * attrglbsiz),
                      senddspptr, (size_t) (grafptr->procglbnbr * MAX (sizeof (int), sizeof (byte *))), /* TRICK: use senddsptab (int *) as attrdsptab (byte **) */
@@ -249,9 +260,12 @@ const MPI_Datatype            attrglbtype)        /* Attribute datatype       */
   if (dgraphHaloSync2 (grafptr, attrgsttab, attrglbtype, &attrsndtab, &senddsptab, &recvdsptab, &requtab) != 0) /* Prepare communication arrays */
     return (1);
 
-  o = 0;                                          /* Assume success               */
-  if ((grafptr->flagval & DGRAPHCOMMPTOP) != 0) { /* If point-to-point exchange   */
-    MPI_Aint              attrglbsiz;             /* Extent of attribute datatype */
+  o = 0;                                          /* Assume success                               */
+  if ((grafptr->flagval & DGRAPHCOMMPTOP) != 0) { /* If point-to-point exchange                   */
+#if ((defined MPI_VERSION) && (MPI_VERSION >= 3))
+    MPI_Aint              attrglbtmp;             /* Lower bound of attribute datatype (not used) */
+#endif /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
+    MPI_Aint              attrglbsiz;             /* Extent of attribute datatype                 */
     const int * restrict  procrcvtab;
     const int * restrict  procsndtab;
     const int * restrict  procngbtab;
@@ -264,7 +278,11 @@ const MPI_Datatype            attrglbtype)        /* Attribute datatype       */
     procngbtab = grafptr->procngbtab;
     procngbnbr = grafptr->procngbnbr;
     procrcvtab = grafptr->procrcvtab;
+#if ((defined MPI_VERSION) && (MPI_VERSION >= 3))
+    MPI_Type_get_extent (attrglbtype, &attrglbtmp, &attrglbsiz); /* Get type extent */
+#else /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
     MPI_Type_extent (attrglbtype, &attrglbsiz);   /* Get type extent */
+#endif /* ((defined MPI_VERSION) && (MPI_VERSION >= 3)) */
     for (procngbnum = procngbnbr - 1, requnbr = 0; procngbnum >= 0; procngbnum --, requnbr ++) { /* Post receives first */
       int                 procglbnum;
 
