@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -42,11 +42,13 @@
 /**   DATES      : # Version 3.2  : from : 19 oct 1996     **/
 /**                                 to   : 21 aug 1998     **/
 /**                # Version 4.0  : from : 19 dec 2001     **/
-/**                                 to     28 dec 2004     **/
+/**                                 to   : 28 dec 2004     **/
 /**                # Version 5.0  : from : 25 jul 2007     **/
-/**                                 to     25 jul 2007     **/
+/**                                 to   : 25 jul 2007     **/
 /**                # Version 5.1  : from : 04 nov 2010     **/
-/**                                 to     04 nov 2010     **/
+/**                                 to   : 04 nov 2010     **/
+/**                # Version 6.0  : from : 08 may 2018     **/
+/**                                 to   : 06 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -68,6 +70,7 @@
 
 #define ORDERCBLKOTHR               0x0000        /*+ Other ordering node              +*/
 #define ORDERCBLKNEDI               0x0001        /*+ Nested dissection separator node +*/
+#define ORDERCBLKDICO               0x0002        /*+ Disconnected components node     +*/
 
 /*
 **  The type and structure definitions.
@@ -112,22 +115,19 @@ typedef struct Order_ {
 **  The function prototypes.
 */
 
-#ifndef ORDER
-#define static
-#endif
+#ifdef ORDER
+static void                 orderExit2          (OrderCblk * const, const Gnum);
+static void                 orderRang2          (Gnum ** const, Gnum * const, const OrderCblk * const);
+static void                 orderTree2          (Gnum * restrict const, Gnum * restrict const, const OrderCblk * restrict const, Gnum);
+#endif /* ORDER */
 
 int                         orderInit           (Order * const, const Gnum, const Gnum, Gnum * const);
 void                        orderExit           (Order * const);
-static void                 orderExit2          (OrderCblk * const, const Gnum);
 int                         orderLoad           (Order * restrict const, const Gnum * restrict const, FILE * restrict const);
 int                         orderSave           (const Order * restrict const, const Gnum * restrict const, FILE * restrict const);
 int                         orderSaveMap        (const Order * const, const Gnum * restrict const, FILE * restrict const);
 int                         orderSaveTree       (const Order * const, const Gnum * restrict const, FILE * restrict const);
 void                        orderPeri           (const Gnum * const, const Gnum, const Gnum, Gnum * const, const Gnum);
 void                        orderRang           (const Order * const, Gnum * const);
-static void                 orderRang2          (Gnum ** const, Gnum * const, const OrderCblk * const);
 void                        orderTree           (const Order * restrict const, Gnum * restrict const);
-static void                 orderTree2          (Gnum * restrict const, Gnum * restrict const, const OrderCblk * restrict const, Gnum);
 int                         orderCheck          (const Order * const);
-
-#undef static
