@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2011,2012,2018,2021 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -8,13 +8,13 @@
 ** use, modify and/or redistribute the software under the terms of the
 ** CeCILL-C license as circulated by CEA, CNRS and INRIA at the following
 ** URL: "http://www.cecill.info".
-** 
+**
 ** As a counterpart to the access to the source code and rights to copy,
 ** modify and redistribute granted by the license, users are provided
 ** only with a limited warranty and the software's author, the holder of
 ** the economic rights, and the successive licensors have only limited
 ** liability.
-** 
+**
 ** In this respect, the user's attention is drawn to the risks associated
 ** with loading, using, modifying and/or developing or reproducing the
 ** software by the user in light of its specific status of free software,
@@ -25,7 +25,7 @@
 ** their requirements in conditions enabling the security of their
 ** systems and/or data to be ensured and, more generally, to use and
 ** operate it in the same conditions as regards security.
-** 
+**
 ** The fact that you are presently reading this means that you have had
 ** knowledge of the CeCILL-C license and that you accept its terms.
 */
@@ -39,21 +39,25 @@
 /**                This module contains output routines.   **/
 /**                                                        **/
 /**   DATES      : # Version 2.0  : from : 07 oct 1994     **/
-/**                                 to     23 dec 1994     **/
+/**                                 to   : 23 dec 1994     **/
 /**                # Version 3.0  : from : 14 jul 1995     **/
-/**                                 to     03 oct 1995     **/
+/**                                 to   : 03 oct 1995     **/
 /**                # Version 3.1  : from : 28 mar 1996     **/
-/**                                 to     03 jun 1996     **/
+/**                                 to   : 03 jun 1996     **/
 /**                # Version 3.2  : from : 02 dec 1996     **/
-/**                                 to     05 jun 1998     **/
+/**                                 to   : 05 jun 1998     **/
 /**                # Version 3.3  : from : 29 may 1999     **/
 /**                                 to   : 03 jun 1999     **/
 /**                # Version 4.0  : from : 11 dec 2001     **/
-/**                                 to     11 dec 2001     **/
+/**                                 to   : 11 dec 2001     **/
 /**                # Version 5.0  : from : 25 may 2007     **/
-/**                                 to     18 jun 2007     **/
+/**                                 to   : 18 jun 2007     **/
 /**                # Version 5.1  : from : 25 oct 2007     **/
-/**                                 to     14 feb 2011     **/
+/**                                 to   : 14 feb 2011     **/
+/**                # Version 6.0  : from : 01 jan 2012     **/
+/**                                 to   : 21 may 2018     **/
+/**                # Version 6.1  : from : 04 apr 2021     **/
+/**                                 to   : 04 apr 2021     **/
 /**                                                        **/
 /************************************************************/
 
@@ -256,11 +260,11 @@ FILE * const                stream)               /* Output stream
 {
   void             (* outcolor) (const SCOTCH_Num, double[]); /* Color routine   */
   O_InvMeshPath *     pattab;                     /* Array of path building data */
-  int *               idxtab;                     /* Array of indexes            */
-  int                 idxnbr;                     /* Number of indexes           */
+  SCOTCH_Num *        idxtab;                     /* Array of indexes            */
+  SCOTCH_Num          idxnbr;                     /* Number of indexes           */
   time_t              pictime;                    /* Creation time               */
   double              color[3];                   /* Vertex color                */
-  int                 i, j, k;
+  SCOTCH_Num          i, j, k;
 
   if (geomptr->verttab == NULL) {
     errorPrint ("outDrawInvMesh: geometry not provided");
@@ -271,8 +275,8 @@ FILE * const                stream)               /* Output stream
 
   outcolor = (O_outParam.InvMesh.color == 'c') ? outColorColor : outColorBlw; /* Select color output routine */
 
-  if (((idxtab = (int *)           memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (int))) == NULL) ||
-      ((pattab = (O_InvMeshPath *) memAlloc (grafptr->vertnbr * sizeof (O_InvMeshPath))) == NULL)) {
+  if (((idxtab = (SCOTCH_Num *)    memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (SCOTCH_Num)))    == NULL) ||
+      ((pattab = (O_InvMeshPath *) memAlloc (grafptr->vertnbr *           sizeof (O_InvMeshPath))) == NULL)) {
     errorPrint ("outDrawInvMesh: out of memory");
     if (idxtab != NULL)
       memFree (idxtab);
@@ -358,10 +362,7 @@ FILE * const                stream)               /* Output stream
   for (i = 0; i < idxnbr - 1; i ++) {
     if ((i % 8) == 0)
       fprintf (stream, "\n");
-    if (idxtab[i] == ~0)
-      fprintf (stream, "\t-1,");
-    else
-      fprintf (stream, "\t%u,", idxtab[i]);
+    fprintf (stream, "\t" SCOTCH_NUMSTRING ",", idxtab[i]); /* ~0 is "1" */
   }
   if (((idxnbr - 1) % 8) == 0)
     fprintf (stream, "\n");
@@ -509,8 +510,8 @@ const C_Geometry * const    geomptr,              /* Graph geometry, sorted by v
 const C_Mapping * const     mapptr,               /* Result mapping, sorted by vertex label  */
 FILE * const                stream)               /* Output stream                           */
 {
-  int                 idxnbr;                     /* Number of indexes                               */
-  int *               idxtab;                     /* Array of indexes                                */
+  SCOTCH_Num          idxnbr;                     /* Number of indexes                               */
+  SCOTCH_Num *        idxtab;                     /* Array of indexes                                */
   O_PosMeshPath *     pattab;                     /* Array of path building data                     */
   O_PosMeshVertex *   pictab;                     /* Array of 2D coordinates, sorted by vertex index */
   O_Point             picmin;                     /* Picture minimum and maximum coordinates         */
@@ -520,18 +521,18 @@ FILE * const                stream)               /* Output stream
   double              picsrad;                    /* Square of circle radius */
   time_t              pictime;                    /* Creation time           */
   double              color[3];                   /* Color values            */
-  int                 i, j, k;
+  SCOTCH_Num          i, j, k;
 
   if (geomptr->verttab == NULL) {
     errorPrint ("outDrawPosMesh: geometry not provided");
-    return      (1);
+    return     (1);
   }
 
   time (&pictime);                                /* Get current time */
 
-  if (((pictab = (O_PosMeshVertex *) memAlloc (grafptr->vertnbr * sizeof (O_PosMeshVertex))) == NULL) ||
-      ((idxtab = (int *)             memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (int)))   == NULL) ||
-      ((pattab = (O_PosMeshPath *)   memAlloc (grafptr->vertnbr * sizeof (O_PosMeshPath)))   == NULL)) {
+  if (((pictab = (O_PosMeshVertex *) memAlloc (grafptr->vertnbr *           sizeof (O_PosMeshVertex))) == NULL) ||
+      ((idxtab = (SCOTCH_Num *)      memAlloc ((grafptr->edgenbr / 2) * 3 * sizeof (SCOTCH_Num)))      == NULL) ||
+      ((pattab = (O_PosMeshPath *)   memAlloc (grafptr->vertnbr *           sizeof (O_PosMeshPath)))   == NULL)) {
     errorPrint ("outDrawPosMesh: out of memory");
     if (pictab != NULL) {
       if (idxtab != NULL)
@@ -720,7 +721,9 @@ FILE * const                stream)               /* Output stream
 
   fprintf (stream, "/A  { 0 360 arc fill } bind def\n"); /* Macro definitions */
   if (O_outParam.PosMesh.color == 'c') {          /* If color output          */
-    for (i = 0; i < O_POSMESHCOLNBR; i ++) {      /* Build color indexes      */
+    int                 i;
+
+    for (i = 0; i < O_POSMESHCOLNBR; i ++) {      /* Build color indices */
       outColorColor (i, color);
       fprintf (stream, "/C%c { %g %g %g setrgbcolor } bind def\n",
                ('a' + i), color[0], color[1], color[2]);
@@ -767,7 +770,7 @@ FILE * const                stream)               /* Output stream
           if (O_outParam.PosMesh.color == 'c')
             fprintf (stream, "C%c\n", 'a' + pictab[i].col);
           else
-            fprintf (stream, "%u G\n", pictab[i].col);
+            fprintf (stream, "%d G\n", pictab[i].col);
           j = i;                                  /* Record the new current color */
         }
 
